@@ -213,7 +213,6 @@ public:
 	void launch_reference ();
 	void launch_tracker ();
 	void launch_subscribe ();
-	void launch_cheat_sheet ();
 	void launch_website ();
 	void launch_website_dev ();
 	void launch_forums ();
@@ -562,7 +561,7 @@ private:
 
 
 	ArdourWidgets::ArdourVSpacer      meterbox_spacer;
-	ArdourWidgets::ArdourVSpacer      meterbox_spacer2;
+	Gtk::HBox                         meterbox_spacer2;
 
 	ArdourWidgets::ArdourButton auto_return_button;
 	ArdourWidgets::ArdourButton follow_edits_button;
