@@ -65,6 +65,7 @@
 
 #include "widgets/ardour_button.h"
 #include "widgets/ardour_dropdown.h"
+#include "widgets/ardour_spacer.h"
 #include "widgets/pane.h"
 
 #include "ardour_dialog.h"
@@ -329,6 +330,7 @@ public:
 	void export_selection ();
 	void export_range ();
 	void export_region ();
+	void quick_export ();
 
 	/* export for analysis only */
 	void loudness_assistant (bool);
@@ -952,16 +954,16 @@ private:
 	ArdourCanvas::Rectangle* _canvas_drop_zone;
 	bool canvas_drop_zone_event (GdkEvent* event);
 
-	Glib::RefPtr<Gtk::ToggleAction> ruler_timecode_action;
-	Glib::RefPtr<Gtk::ToggleAction> ruler_bbt_action;
-	Glib::RefPtr<Gtk::ToggleAction> ruler_samples_action;
 	Glib::RefPtr<Gtk::ToggleAction> ruler_minsec_action;
-	Glib::RefPtr<Gtk::ToggleAction> ruler_tempo_action;
+	Glib::RefPtr<Gtk::ToggleAction> ruler_timecode_action;
+	Glib::RefPtr<Gtk::ToggleAction> ruler_samples_action;
+	Glib::RefPtr<Gtk::ToggleAction> ruler_bbt_action;
 	Glib::RefPtr<Gtk::ToggleAction> ruler_meter_action;
-	Glib::RefPtr<Gtk::ToggleAction> ruler_marker_action;
+	Glib::RefPtr<Gtk::ToggleAction> ruler_tempo_action;
 	Glib::RefPtr<Gtk::ToggleAction> ruler_range_action;
 	Glib::RefPtr<Gtk::ToggleAction> ruler_loop_punch_action;
 	Glib::RefPtr<Gtk::ToggleAction> ruler_cd_marker_action;
+	Glib::RefPtr<Gtk::ToggleAction> ruler_marker_action;
 	Glib::RefPtr<Gtk::ToggleAction> ruler_cue_marker_action;
 	bool                            no_ruler_shown_update;
 
@@ -1555,6 +1557,7 @@ private:
 	void clear_markers ();
 	void clear_xrun_markers ();
 	void clear_ranges ();
+	void clear_cues ();
 	void clear_locations ();
 	void unhide_markers ();
 	void unhide_ranges ();
@@ -1741,7 +1744,6 @@ private:
 
 	Temporal::TempoMap::WritableSharedPtr begin_tempo_map_edit ();
 	void abort_tempo_map_edit ();
-	void commit_tempo_map_edit (Temporal::TempoMap::WritableSharedPtr&, bool with_update = false);
 	void mid_tempo_per_track_update (TimeAxisView&);
 	void mid_tempo_per_region_update (RegionView*);
 	bool ignore_map_change;
@@ -1754,6 +1756,9 @@ private:
 
 	void mid_tempo_change (MidTempoChanges);
 
+protected:
+	void _commit_tempo_map_edit (Temporal::TempoMap::WritableSharedPtr&, bool with_update = false);
+
 private:
 	friend class DragManager;
 	friend class EditorRouteGroups;
@@ -1975,6 +1980,8 @@ private:
 	Gtk::HBox snap_box;
 	Gtk::HBox draw_box;
 
+	ArdourWidgets::ArdourVSpacer _draw_box_spacer;
+
 	Gtk::HBox ebox_hpacker;
 	Gtk::VBox ebox_vpacker;
 
