@@ -369,8 +369,10 @@ Editor::mouse_mode_toggled (MouseMode m)
 
 	if (mouse_mode == MouseDraw) {
 		draw_box.show();
+		_draw_box_spacer.show();
 	} else {
 		draw_box.hide();
+		_draw_box_spacer.hide();
 	}
 
 
@@ -1694,7 +1696,6 @@ Editor::button_release_handler (ArdourCanvas::Item* item, GdkEvent* event, ItemT
 
 			case CueMarkerBarItem:
 				snap_to (where, Temporal::RoundNearest, SnapToGrid_Scaled, true);
-				std::cerr << "cue marker will be at " << where << " beats = " << where.beats() << std::endl;
 				popup_ruler_menu (where, item_type);
 				break;
 
