@@ -93,6 +93,7 @@ class MouseCursors;
 class RegionView;
 class RouteTimeAxisView;
 class Selection;
+class SimpleExport;
 class StripableTimeAxisView;
 class TempoCurve;
 class TempoMarker;
@@ -177,7 +178,7 @@ public:
 	/** Set the mouse mode (gain, object, range, timefx etc.)
 	 * @param m Mouse mode (defined in editing_syms.h)
 	 * @param force Perform the effects of the change even if no change is required
-	 * (ie even if the current mouse mode is equal to @param m)
+	 * (ie even if the current mouse mode is equal to @p m)
 	 */
 	virtual void set_mouse_mode (Editing::MouseMode m, bool force = false) = 0;
 
@@ -300,6 +301,9 @@ public:
 	/** Open export dialog with current range pre-selected */
 	virtual void export_range () = 0;
 
+	/** Open Simple Export Dialog */
+	virtual void quick_export () = 0;
+
 	virtual void loudness_assistant (bool) = 0;
 
 	virtual void register_actions () = 0;
@@ -514,6 +518,12 @@ public:
 	virtual void abort_reversible_command () = 0;
 	virtual void commit_reversible_command () = 0;
 
+	virtual Temporal::TempoMap::WritableSharedPtr begin_tempo_map_edit () = 0;
+	virtual void abort_tempo_map_edit () = 0;
+	void commit_tempo_map_edit (Temporal::TempoMap::WritableSharedPtr& map, bool with_update = false) {
+		_commit_tempo_map_edit (map, with_update);
+	}
+
 	virtual void access_action (const std::string&, const std::string&) = 0;
 	virtual void set_toggleaction (const std::string&, const std::string&, bool) = 0;
 
@@ -577,6 +587,7 @@ protected:
 	friend class DisplaySuspender;
 	virtual void suspend_route_redisplay () = 0;
 	virtual void resume_route_redisplay () = 0;
+	virtual void _commit_tempo_map_edit (Temporal::TempoMap::WritableSharedPtr&, bool with_update) = 0;
 
 	GATOMIC_QUAL gint _suspend_route_redisplay_counter;
 };
