@@ -101,14 +101,11 @@ public:
 	}
 
 public:
+	float speed_as_fract (float) const;
+	float fract_as_speed (float) const;
+
 	static int speed_as_semitones (float, bool&);
-	static int fract_as_semitones (float, bool&);
-
-	static float semitones_as_speed (int, bool);
-	static float semitones_as_fract (int, bool);
-
-	static int   speed_as_cents (float, bool&);
-	static float cents_as_speed (int, bool);
+	static int speed_as_cents (float, bool&);
 
 protected:
 	bool                                   _hovering;
