@@ -55,7 +55,7 @@ using namespace PBD;
 using namespace Gtk;
 using namespace Gtkmm2ext;
 
-TimeFXDialog::TimeFXDialog (Editor& e, bool pitch, samplecnt_t oldlen, samplecnt_t new_length, samplepos_t position)
+TimeFXDialog::TimeFXDialog (Editor& e, bool pitch, timecnt_t const & oldlen, timecnt_t const & new_length, Temporal::ratio_t const & ratio, timepos_t const & position)
 	: ArdourDialog (X_("time fx dialog"))
 	, editor (e)
 	, pitching (pitch)
@@ -71,6 +71,7 @@ TimeFXDialog::TimeFXDialog (Editor& e, bool pitch, samplecnt_t oldlen, samplecnt
 	, pitch_octave_spinner (pitch_octave_adjustment)
 	, pitch_semitone_spinner (pitch_semitone_adjustment)
 	, pitch_cent_spinner (pitch_cent_adjustment)
+	, duration_ratio (ratio)
 	, duration_adjustment (100.0, -1000.0, 1000.0, 1.0, 10.0)
 	, duration_clock (0)
 	, ignore_adjustment_change (false)
@@ -100,30 +101,32 @@ TimeFXDialog::TimeFXDialog (Editor& e, bool pitch, samplecnt_t oldlen, samplecnt
 
 	upper_button_box.set_spacing (6);
 
-	l = manage (new Label (_("<b>Options</b>"), Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false ));
+	l = manage (new Label (_("<b>Options</b>"), Gtk::ALIGN_START, Gtk::ALIGN_CENTER, false ));
 	l->set_use_markup ();
 
 	upper_button_box.pack_start (*l, false, false);
 
+	/* if the ratio is already set, do not allow adjustment */
+
 	if (pitching) {
 		Table* table = manage (new Table (4, 3, false));
 		table->set_row_spacings	(6);
 		table->set_col_spacing	(1, 6);
-		l = manage (new Label ("", Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false )); //Common gnome way for padding
+		l = manage (new Label ("", Gtk::ALIGN_START, Gtk::ALIGN_CENTER, false )); //Common gnome way for padding
 		l->set_padding (8, 0);
 		table->attach (*l, 0, 1, 0, 4, Gtk::FILL, Gtk::FILL, 0, 0);
 
-		l = manage (new Label (_("Octaves:"), Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false));
+		l = manage (new Label (_("Octaves:"), Gtk::ALIGN_START, Gtk::ALIGN_CENTER, false));
 		table->attach (*l, 1, 2, 0, 1, Gtk::FILL, Gtk::EXPAND, 0, 0);
 		table->attach (pitch_octave_spinner, 2, 3, 0, 1, Gtk::FILL, Gtk::EXPAND & Gtk::FILL, 0, 0);
 		pitch_octave_spinner.set_activates_default ();
 
-		l = manage (new Label (_("Semitones:"), Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false));
+		l = manage (new Label (_("Semitones:"), Gtk::ALIGN_START, Gtk::ALIGN_CENTER, false));
 		table->attach (*l, 1, 2, 1, 2, Gtk::FILL, Gtk::EXPAND, 0, 0);
 		table->attach (pitch_semitone_spinner, 2, 3, 1, 2, Gtk::FILL, Gtk::EXPAND & Gtk::FILL, 0, 0);
 		pitch_semitone_spinner.set_activates_default ();
 
-		l = manage (new Label (_("Cents:"), Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false));
+		l = manage (new Label (_("Cents:"), Gtk::ALIGN_START, Gtk::ALIGN_CENTER, false));
 		pitch_cent_spinner.set_digits (1);
 		table->attach (*l, 1, 2, 2, 3, Gtk::FILL, Gtk::EXPAND, 0, 0);
 		table->attach (pitch_cent_spinner, 2, 3, 2, 3, Gtk::FILL, Gtk::EXPAND & Gtk::FILL, 0, 0);
@@ -145,9 +148,8 @@ TimeFXDialog::TimeFXDialog (Editor& e, bool pitch, samplecnt_t oldlen, samplecnt
 		vector<string> strings;
 		duration_clock = manage (new AudioClock (X_("stretch"), true, X_("stretch"), true, false, true, false, true));
 		duration_clock->set_session (e.session());
-		duration_clock->set (new_length, true);
 		duration_clock->set_mode (AudioClock::BBT);
-		duration_clock->set_bbt_reference (position);
+		duration_clock->set_duration (timecnt_t (new_length, position));
 
 		Gtk::Alignment* clock_align = manage (new Gtk::Alignment);
 		clock_align->add (*duration_clock);
@@ -158,11 +160,15 @@ TimeFXDialog::TimeFXDialog (Editor& e, bool pitch, samplecnt_t oldlen, samplecnt
 		table->attach (*clock_align, 1, 2, row, row+1, Gtk::AttachOptions (Gtk::EXPAND|Gtk::FILL), Gtk::FILL, 0, 0);
 		row++;
 
-		const double fract = ((double) new_length) / original_length;
 		/* note the *100.0 to convert fract into a percentage */
-		duration_adjustment.set_value (fract*100.0);
+		duration_adjustment.set_value (duration_ratio.to_double() * 100.0);
+
 		Gtk::SpinButton* spinner = manage (new Gtk::SpinButton (duration_adjustment, 1.0, 3));
 
+		if (duration_ratio != Temporal::ratio_t (1, 1)) {
+			spinner->set_sensitive (false);
+		}
+
 		l = manage (new Gtk::Label (_("Percent")));
 		table->attach (*l, 0, 1, row, row+1, Gtk::FILL, Gtk::FILL, 0, 0);
 		table->attach (*spinner, 1, 2, row, row+1, Gtk::FILL, Gtk::FILL, 0, 0);
@@ -202,7 +208,7 @@ TimeFXDialog::TimeFXDialog (Editor& e, bool pitch, samplecnt_t oldlen, samplecnt
 	VBox* progress_box = manage (new VBox);
 	progress_box->set_spacing (6);
 
-	l = manage (new Label (_("<b>Progress</b>"), Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false));
+	l = manage (new Label (_("<b>Progress</b>"), Gtk::ALIGN_START, Gtk::ALIGN_CENTER, false));
 	l->set_use_markup ();
 
 	progress_box->pack_start (*l, false, false);
@@ -259,14 +265,18 @@ TimeFXDialog::delete_in_progress (GdkEventAny*)
 	return TRUE;
 }
 
-float
+Temporal::ratio_t
 TimeFXDialog::get_time_fraction () const
 {
 	if (pitching) {
-		return 1.0;
+		return Temporal::ratio_t (1, 1);
 	}
 
-	return duration_adjustment.get_value() / 100.0;
+	if (duration_ratio != Temporal::ratio_t (1, 1)) {
+		return duration_ratio;
+	}
+
+	return Temporal::ratio_t (duration_adjustment.get_value(), 100);
 }
 
 float
@@ -299,9 +309,14 @@ TimeFXDialog::duration_adjustment_changed ()
 		return;
 	}
 
-	PBD::Unwinder<bool> uw (ignore_clock_change, true);
+	if (duration_adjustment.get_value() == 0.0) {
+		return;
+	}
 
-	duration_clock->set ((samplecnt_t) (original_length * (duration_adjustment.get_value()/ 100.0)));
+	PBD::Unwinder<bool> uw (ignore_clock_change, true);
+	timecnt_t dur = original_length.scale (Temporal::ratio_t (duration_adjustment.get_value(), 100.0));
+
+	duration_clock->set_duration (dur);
 }
 
 void
@@ -313,5 +328,5 @@ TimeFXDialog::duration_clock_changed ()
 
 	PBD::Unwinder<bool> uw (ignore_adjustment_change, true);
 
-	duration_adjustment.set_value (100.0 * (duration_clock->current_duration() / (double) original_length));
+	duration_adjustment.set_value (100.0 * (duration_clock->current_duration() / original_length).to_double());
 }
