@@ -107,6 +107,8 @@ public:
 
 	void get_connected_latency_range (LatencyRange& range, bool playback) const;
 
+	void collect_latency_from_backend (LatencyRange& range, bool playback) const;
+
 	void set_private_latency_range (LatencyRange& range, bool playback);
 	const LatencyRange&  private_latency_range (bool playback) const;
 
@@ -119,6 +121,7 @@ public:
 	virtual void cycle_start (pframes_t);
 	virtual void cycle_end (pframes_t) = 0;
 	virtual void cycle_split () = 0;
+	virtual void reinit () {}
 	virtual Buffer& get_buffer (pframes_t nframes) = 0;
 	virtual void flush_buffers (pframes_t /*nframes*/) {}
 	virtual void transport_stopped () {}
@@ -137,7 +140,8 @@ public:
 	static PBD::Signal0<void> PortDrop;
 	static PBD::Signal0<void> PortSignalDrop;
 
-	static void set_speed_ratio (double s);
+	static void set_varispeed_ratio (double s); //< varispeed playback
+	static bool set_engine_ratio (double session, double engine); //< SR mismatch
 	static void set_cycle_samplecnt (pframes_t n);
 
 	static samplecnt_t port_offset() { return _global_port_buffer_offset; }
@@ -148,14 +152,20 @@ public:
 		_global_port_buffer_offset += n;
 	}
 
-	virtual XMLNode& get_state (void) const;
+	virtual XMLNode& get_state () const;
 	virtual int set_state (const XMLNode&, int version);
 
 	static std::string state_node_name;
 
 	static pframes_t cycle_nframes () { return _cycle_nframes; }
 	static double speed_ratio () { return _speed_ratio; }
+	static double engine_ratio () { return _engine_ratio; }
+	static double resample_ratio () { return _resample_ratio; } // == _speed_ratio * _engine_ratio
+
 	static uint32_t resampler_quality () { return _resampler_quality; }
+	static uint32_t resampler_latency () { return _resampler_latency; }
+	static bool     can_varispeed ()     { return _resampler_latency > 0; }
+	static bool     setup_resampler (uint32_t q = 17);
 
 protected:
 
@@ -172,7 +182,8 @@ protected:
 	LatencyRange _private_capture_latency;
 
 	static double _speed_ratio;
-	static const uint32_t _resampler_quality; /* also latency of the resampler */
+	static double _engine_ratio;
+	static double _resample_ratio; // = _speed_ratio * _engine_ratio (cached)
 
 private:
 	std::string _name;  ///< port short name
@@ -185,6 +196,9 @@ private:
 	*/
 	std::set<std::string> _connections;
 
+	static uint32_t _resampler_quality; // 8 <= q <= 96
+	static uint32_t _resampler_latency; // = _resampler_quality - 1
+
 	void port_connected_or_disconnected (boost::weak_ptr<Port>, boost::weak_ptr<Port>, bool);
 	void signal_drop ();
 	void session_global_drop ();
