@@ -1215,6 +1215,7 @@ public:
 	boost::shared_ptr<PBD::Controllable> recently_touched_controllable () const;
 
 	bool apply_nth_mixer_scene (size_t);
+	bool apply_nth_mixer_scene (size_t, RouteList const&);
 	void store_nth_mixer_scene (size_t);
 	bool nth_mixer_scene_valid (size_t) const;
 
@@ -1374,6 +1375,9 @@ public:
 	void trigger_cue_row (int32_t);
 	CueEvents const & cue_events() const { return _cue_events; }
 
+	int num_triggerboxes () const;
+	boost::shared_ptr<TriggerBox> triggerbox_at (int32_t route_index) const;
+	TriggerPtr trigger_at (int32_t route_index, int32_t row_index) const;
 	bool bang_trigger_at(int32_t route_index, int32_t row_index);
 	bool unbang_trigger_at(int32_t route_index, int32_t row_index);
 
