@@ -47,7 +47,7 @@ ARDOUR::samplecnt_t DiskWriter::_chunk_samples = DiskWriter::default_chunk_sampl
 PBD::Signal0<void> DiskWriter::Overrun;
 
 DiskWriter::DiskWriter (Session& s, Track& t, string const & str, DiskIOProcessor::Flag f)
-	: DiskIOProcessor (s, t, X_("recorder:") + str, f)
+        : DiskIOProcessor (s, t, X_("recorder:") + str, f, Config->get_default_automation_time_domain())
 	, _capture_captured (0)
 	, _was_recording (false)
 	, _xrun_flag (false)
@@ -169,12 +169,13 @@ DiskWriter::check_record_status (samplepos_t transport_sample, double speed, boo
 
 		Location* loc;
 		if  (_session.config.get_punch_in () && 0 != (loc = _session.locations()->auto_punch_location ())) {
-			_capture_start_sample = loc->start ();
+			_capture_start_sample = loc->start_sample ();
 		} else if (_loop_location) {
-			_capture_start_sample = _loop_location->start ();
+			_capture_start_sample = _loop_location->start_sample ();
 			if (_last_possibly_recording & transport_rolling) {
 				_accumulated_capture_offset = _playback_offset + transport_sample - _session.transport_sample (); // + rec_offset;
 			}
+
 		} else {
 			_capture_start_sample = _session.transport_sample ();
 		}
@@ -191,7 +192,7 @@ DiskWriter::check_record_status (samplepos_t transport_sample, double speed, boo
 			 * We should allow to move it or at least allow to disable punch-out
 			 * while rolling..
 			 */
-			_last_recordable_sample = loc->end ();
+			_last_recordable_sample = loc->end_sample ();
 			if (_alignment_style == ExistingMaterial) {
 				_last_recordable_sample += _capture_offset + _playback_offset;
 			}
@@ -218,9 +219,9 @@ DiskWriter::check_record_status (samplepos_t transport_sample, double speed, boo
 		/* set _capture_start_sample early on to calculate MIDI _accumulated_capture_offset */
 		Location* loc;
 		if  (_session.config.get_punch_in () && 0 != (loc = _session.locations()->auto_punch_location ())) {
-			_capture_start_sample = loc->start ();
+			_capture_start_sample = loc->start_sample ();
 		} else if (_loop_location) {
-			_capture_start_sample = _loop_location->start ();
+			_capture_start_sample = _loop_location->start_sample ();
 		} else if ((possibly_recording & rec_ready) == rec_ready) {
 			/* count-in, pre-roll */
 			_capture_start_sample = _session.transport_sample ();
@@ -234,14 +235,14 @@ DiskWriter::check_record_status (samplepos_t transport_sample, double speed, boo
 }
 
 void
-DiskWriter::calculate_record_range (Evoral::OverlapType ot, samplepos_t transport_sample, samplecnt_t nframes, samplecnt_t & rec_nframes, samplecnt_t & rec_offset)
+DiskWriter::calculate_record_range (Temporal::OverlapType ot, samplepos_t transport_sample, samplecnt_t nframes, samplecnt_t & rec_nframes, samplecnt_t & rec_offset)
 {
 	switch (ot) {
-	case Evoral::OverlapNone:
+	case Temporal::OverlapNone:
 		rec_nframes = 0;
 		break;
 
-	case Evoral::OverlapInternal:
+	case Temporal::OverlapInternal:
 		/*     ----------    recrange
 		 *       |---|       transrange
 		 */
@@ -249,7 +250,7 @@ DiskWriter::calculate_record_range (Evoral::OverlapType ot, samplepos_t transpor
 		rec_offset = 0;
 		break;
 
-	case Evoral::OverlapStart:
+	case Temporal::OverlapStart:
 		/*    |--------|    recrange
 		 *  -----|          transrange
 		 */
@@ -259,7 +260,7 @@ DiskWriter::calculate_record_range (Evoral::OverlapType ot, samplepos_t transpor
 		}
 		break;
 
-	case Evoral::OverlapEnd:
+	case Temporal::OverlapEnd:
 		/*    |--------|    recrange
 		 *       |--------  transrange
 		 */
@@ -267,7 +268,7 @@ DiskWriter::calculate_record_range (Evoral::OverlapType ot, samplepos_t transpor
 		rec_offset = 0;
 		break;
 
-	case Evoral::OverlapExternal:
+	case Temporal::OverlapExternal:
 		/*    |--------|    recrange
 		 *  --------------  transrange
 		 */
@@ -366,7 +367,7 @@ DiskWriter::set_align_style (AlignStyle a, bool force)
 }
 
 XMLNode&
-DiskWriter::state ()
+DiskWriter::state () const
 {
 	XMLNode& node (DiskIOProcessor::state ());
 	node.set_property (X_("type"), X_("diskwriter"));
@@ -394,7 +395,16 @@ void
 DiskWriter::non_realtime_locate (samplepos_t position)
 {
 	if (_midi_write_source) {
-		_midi_write_source->set_natural_position (position);
+		timepos_t pos;
+
+		if (time_domain() == Temporal::AudioTime) {
+			pos = timepos_t (position);
+		} else {
+			const timepos_t b (position);
+			pos = timepos_t (b.beats());
+		}
+
+		_midi_write_source->set_natural_position (pos);
 	}
 
 	DiskIOProcessor::non_realtime_locate (position);
@@ -413,11 +423,10 @@ void
 DiskWriter::run (BufferSet& bufs, samplepos_t start_sample, samplepos_t end_sample,
                  double speed, pframes_t nframes, bool result_required)
 {
-	if (!_active && !_pending_active) {
+	if (!check_active()) {
 		_xrun_flag = false;
 		return;
 	}
-	_active = _pending_active;
 
 	uint32_t n;
 	boost::shared_ptr<ChannelList> c = channels.reader();
@@ -430,14 +439,14 @@ DiskWriter::run (BufferSet& bufs, samplepos_t start_sample, samplepos_t end_samp
 	bool re = record_enabled ();
 	bool punch_in = _session.config.get_punch_in () && _session.locations()->auto_punch_location ();
 	bool can_record = _session.actively_recording ();
-	can_record |= speed != 0 && _session.get_record_enabled () && punch_in && _session.transport_sample () <= _session.locations()->auto_punch_location ()->start ();
+	can_record |= speed != 0 && _session.get_record_enabled () && punch_in && _session.transport_sample () <= _session.locations()->auto_punch_location ()->start_sample ();
 
 	_need_butler = false;
 
-	const Location* const loop_loc    = _loop_location;
-	samplepos_t           loop_start  = 0;
-	samplepos_t           loop_end    = 0;
-	samplepos_t           loop_length = 0;
+	const Location* const loop_loc = _loop_location;
+	timepos_t loop_start;
+	timepos_t loop_end;
+	timecnt_t loop_length;
 
 	if (_transport_looped && _capture_captured == 0) {
 		_transport_looped = false;
@@ -446,9 +455,9 @@ DiskWriter::run (BufferSet& bufs, samplepos_t start_sample, samplepos_t end_samp
 	if (loop_loc) {
 		get_location_times (loop_loc, &loop_start, &loop_end, &loop_length);
 
-		if (_was_recording && _transport_looped && _capture_captured >= loop_length) {
-			samplecnt_t remain = _capture_captured - loop_length;
-			_capture_captured = loop_length;
+		if (_was_recording && _transport_looped && _capture_captured >= loop_length.samples()) {
+			samplecnt_t remain = _capture_captured - loop_length.samples();
+			_capture_captured = loop_length.samples();
 			loop (_transport_loop_sample);
 			_capture_captured = remain;
 		}
@@ -481,7 +490,7 @@ DiskWriter::run (BufferSet& bufs, samplepos_t start_sample, samplepos_t end_samp
 
 	if (nominally_recording || (re && _was_recording && _session.get_record_enabled() && punch_in)) {
 
-		Evoral::OverlapType ot = Evoral::coverage (_first_recordable_sample, _last_recordable_sample, start_sample, end_sample);
+		Temporal::OverlapType ot = Temporal::coverage_exclusive_ends (_first_recordable_sample, _last_recordable_sample, start_sample, end_sample);
 		// XXX should this be transport_sample + nframes - 1 ? coverage() expects its parameter ranges to include their end points
 		// XXX also, first_recordable_sample & last_recordable_sample may both be == max_samplepos: coverage() will return OverlapNone in that case. Is thak OK?
 		calculate_record_range (ot, start_sample, nframes, rec_nframes, rec_offset);
@@ -498,9 +507,10 @@ DiskWriter::run (BufferSet& bufs, samplepos_t start_sample, samplepos_t end_samp
 				   at the loop start and can handle time wrapping around.
 				   Otherwise, start the source right now as usual.
 				*/
-				_capture_captured     = start_sample - loop_start + rec_offset;
-				_capture_start_sample = loop_start;
-				_first_recordable_sample = loop_start;
+
+				_capture_captured     = start_sample - loop_start.samples() + rec_offset;
+				_capture_start_sample = loop_start.samples();
+				_first_recordable_sample = loop_start.samples();
 
 				if (_alignment_style == ExistingMaterial) {
 					_capture_captured  -= _playback_offset + _capture_offset;
@@ -521,7 +531,14 @@ DiskWriter::run (BufferSet& bufs, samplepos_t start_sample, samplepos_t end_samp
 
 			if (_midi_write_source) {
 				assert (_capture_start_sample);
-				_midi_write_source->mark_write_starting_now (_capture_start_sample.value (), _capture_captured, loop_length);
+
+				timepos_t start (_capture_start_sample.get());
+
+				if (time_domain() != Temporal::AudioTime) {
+					start = timepos_t (start.beats());
+				}
+
+				_midi_write_source->mark_write_starting_now (start, _capture_captured);
 			}
 
 			g_atomic_int_set (&_samples_pending_write, 0);
@@ -629,7 +646,7 @@ DiskWriter::run (BufferSet& bufs, samplepos_t start_sample, samplepos_t end_samp
 				   reconstruct their actual time; future clever MIDI looping should
 				   probably be implemented in the source instead of here.
 				*/
-				const samplecnt_t loop_offset = g_atomic_int_get (&_num_captured_loops) * loop_length;
+				const samplecnt_t loop_offset = g_atomic_int_get (&_num_captured_loops) * loop_length.samples();
 				const samplepos_t event_time = start_sample + loop_offset - _accumulated_capture_offset + ev.time();
 				if (event_time < 0 || event_time < _first_recordable_sample) {
 					/* Event out of range, skip */
@@ -682,9 +699,9 @@ DiskWriter::run (BufferSet& bufs, samplepos_t start_sample, samplepos_t end_samp
 		}
 
 		if (_xrun_flag) {
-			/* There still are `Port::resampler_quality () -1` samples in the resampler
+			/* There still are `Port::resampler_latency ()` samples in the resampler
 			 * buffer from before the xrun. */
-			_xruns.push_back (_capture_captured + Port::resampler_quality () - 1);
+			_xruns.push_back (_capture_captured + Port::resampler_latency ());
 		}
 
 		_capture_captured += rec_nframes;
@@ -743,11 +760,11 @@ DiskWriter::finish_capture (boost::shared_ptr<ChannelList> c)
 	_xruns.clear ();
 
 	if (_loop_location) {
-		samplepos_t loop_start  = 0;
-		samplepos_t loop_end    = 0;
-		samplepos_t loop_length = 0;
+		timepos_t loop_start;
+		timepos_t loop_end;
+		timecnt_t loop_length;
 		get_location_times (_loop_location, &loop_start, &loop_end, &loop_length);
-		ci->loop_offset = g_atomic_int_get (&_num_captured_loops) * loop_length;
+	        ci->loop_offset = g_atomic_int_get (&_num_captured_loops) * loop_length.samples();
 	} else {
 		ci->loop_offset = 0;
 	}
@@ -843,7 +860,7 @@ DiskWriter::prep_record_enable ()
 
 	for (ChannelList::iterator chan = c->begin(); chan != c->end(); ++chan) {
 		capturing_sources.push_back ((*chan)->write_source);
-		Source::Lock lock((*chan)->write_source->mutex());
+		Source::WriterLock lock ((*chan)->write_source->mutex());
 		(*chan)->write_source->mark_streaming_write_started (lock);
 	}
 
@@ -880,9 +897,6 @@ DiskWriter::set_note_mode (NoteMode m)
 	if (mp) {
 		mp->set_note_mode (m);
 	}
-
-	if (_midi_write_source && _midi_write_source->model())
-		_midi_write_source->model()->set_note_mode(m);
 }
 
 void
@@ -1020,8 +1034,8 @@ DiskWriter::do_flush (RunContext ctxt, bool force_flush)
 		}
 
 		if ((total > _chunk_samples) || force_flush) {
-			Source::Lock lm(_midi_write_source->mutex());
-			if (_midi_write_source->midi_write (lm, *_midi_buf, get_capture_start_sample (0), to_write) != to_write) {
+			Source::WriterLock lm(_midi_write_source->mutex());
+			if (_midi_write_source->midi_write (lm, *_midi_buf, timepos_t (get_capture_start_sample (0)), timecnt_t (to_write)) != to_write) {
 				error << string_compose(_("MidiDiskstream %1: cannot write to disk"), id()) << endmsg;
 				return -1;
 			}
@@ -1052,7 +1066,7 @@ DiskWriter::reset_write_sources (bool mark_write_complete, bool /*force*/)
 		if ((*chan)->write_source) {
 
 			if (mark_write_complete) {
-				Source::Lock lock((*chan)->write_source->mutex());
+				Source::WriterLock lock((*chan)->write_source->mutex());
 				(*chan)->write_source->mark_streaming_write_completed (lock);
 				(*chan)->write_source->done_with_peakfile_writes ();
 			}
@@ -1074,7 +1088,7 @@ DiskWriter::reset_write_sources (bool mark_write_complete, bool /*force*/)
 
 	if (_midi_write_source) {
 		if (mark_write_complete) {
-			Source::Lock lm(_midi_write_source->mutex());
+			Source::WriterLock lm(_midi_write_source->mutex());
 			_midi_write_source->mark_streaming_write_completed (lm);
 		}
 	}
@@ -1153,7 +1167,6 @@ DiskWriter::transport_stopped_wallclock (struct tm& when, time_t twhen, bool abo
 
 	finish_capture (c);
 
-
 	/* butler is already stopped, but there may be work to do
 	   to flush remaining data to disk.
 	*/
@@ -1221,7 +1234,7 @@ DiskWriter::transport_stopped_wallclock (struct tm& when, time_t twhen, bool abo
 				Analyser::queue_source_for_analysis (as, true);
 			}
 
-			DEBUG_TRACE (DEBUG::CaptureAlignment, string_compose ("newly captured source %1 length %2\n", as->path(), as->length (0)));
+			DEBUG_TRACE (DEBUG::CaptureAlignment, string_compose ("newly captured source %1 length %2\n", as->path(), as->length ()));
 		}
 
 		if (_midi_write_source) {
@@ -1231,14 +1244,14 @@ DiskWriter::transport_stopped_wallclock (struct tm& when, time_t twhen, bool abo
 
 		(*chan)->write_source->stamp (twhen);
 		(*chan)->write_source->set_captured_xruns (capture_info.front()->xruns);
+		(*chan)->write_source->set_captured_marks (_session.pending_source_markers);
 	}
 
-
 	/* MIDI */
 
 	if (_midi_write_source) {
 
-		if (_midi_write_source->length (capture_info.front()->start) == 0) {
+		if (_midi_write_source->empty()) {
 			/* No data was recorded, so this capture will
 			   effectively be aborted; do the same as we
 			   do for an explicit abort.
@@ -1254,33 +1267,28 @@ DiskWriter::transport_stopped_wallclock (struct tm& when, time_t twhen, bool abo
 
 		/* phew, we have data */
 
-		Source::Lock source_lock(_midi_write_source->mutex());
+		Source::WriterLock source_lock(_midi_write_source->mutex());
 
 		/* figure out the name for this take */
 
 		midi_srcs.push_back (_midi_write_source);
 
-		_midi_write_source->set_natural_position (capture_info.front()->start);
-		_midi_write_source->set_captured_for (_track.name ());
+		_midi_write_source->set_natural_position (timepos_t (capture_info.front()->start));
+		_midi_write_source->set_captured_for (_track.name());
 
 		Glib::DateTime tm (Glib::DateTime::create_now_local (mktime (&when)));
 		_midi_write_source->set_take_id (tm.format ("%F %H.%M.%S"));
 
-		/* set length in beats to entire capture length */
-
-
-		Temporal::Beats total_capture_beats;
-		for (vector<CaptureInfo*>::iterator ci = capture_info.begin(); ci != capture_info.end(); ++ci) {
-			BeatsSamplesConverter converter (_session.tempo_map(), (*ci)->start);
-			total_capture_beats += converter.from ((*ci)->samples);
-		}
-		_midi_write_source->set_length_beats (total_capture_beats);
-
 		/* flush to disk: this step differs from the audio path,
 		   where all the data is already on disk.
 		*/
 
-		_midi_write_source->mark_midi_streaming_write_completed (source_lock, Evoral::Sequence<Temporal::Beats>::ResolveStuckNotes, total_capture_beats);
+		timecnt_t total_capture (0, timepos_t (capture_info.front()->start));
+		for (vector<CaptureInfo*>::iterator ci = capture_info.begin(); ci != capture_info.end(); ++ci) {
+			total_capture += timecnt_t ((*ci)->samples);
+		}
+
+		_midi_write_source->mark_midi_streaming_write_completed (source_lock, Evoral::Sequence<Temporal::Beats>::ResolveStuckNotes, total_capture.beats());
 	}
 
 	_last_capture_sources.insert (_last_capture_sources.end(), audio_srcs.begin(), audio_srcs.end());
