@@ -720,6 +720,7 @@ LadspaPluginInfo::get_presets (bool /*user_only*/) const
 
 	if (set_uris) {
 		for (uint32_t i = 0; i < (uint32_t) set_uris->count; ++i) {
+			// TODO somehow mark factory presets as such..
 			if (char* label = lrdf_get_label (set_uris->items[i])) {
 				p.push_back (Plugin::PresetRecord (set_uris->items[i], label));
 			}
@@ -796,7 +797,8 @@ lrdf_remove_preset (const char* /*source*/, const char *setting_uri)
 	char setting_uri_copy[64];
 	char buf[64];
 
-	strncpy(setting_uri_copy, setting_uri, sizeof(setting_uri_copy));
+	strncpy(setting_uri_copy, setting_uri, sizeof(setting_uri_copy) - 1);
+	setting_uri_copy[sizeof (setting_uri_copy) - 1] = '\0';
 
 	p.subject = setting_uri_copy;
 	strncpy(buf, LADSPA_BASE "hasPortValue", sizeof(buf));
