@@ -145,6 +145,8 @@ Region::make_property_quarks ()
 	DEBUG_TRACE (DEBUG::Properties, string_compose ("quark for tags = %1\n",	Properties::tags.property_id));
 	Properties::contents.property_id = g_quark_from_static_string (X_("contents"));
 	DEBUG_TRACE (DEBUG::Properties, string_compose ("quark for contents = %1\n",	Properties::contents.property_id));
+	Properties::time_domain.property_id = g_quark_from_static_string (X_("time_domain"));
+	DEBUG_TRACE (DEBUG::Properties, string_compose ("quark for time_domain = %1\n",	Properties::time_domain.property_id));
 }
 
 void
@@ -379,7 +381,7 @@ Region::Region (boost::shared_ptr<const Region> other, timecnt_t const & offset)
 	assert (_type == other->data_type());
 }
 
-/** Create a copy of @param other but with different sources. Used by filters */
+/** Create a copy of @p other but with different sources. Used by filters */
 Region::Region (boost::shared_ptr<const Region> other, const SourceList& srcs)
 	: SessionObject (other->session(), other->name())
 	, _type (srcs.front()->type())
@@ -1356,6 +1358,19 @@ Region::_set_state (const XMLNode& node, int version, PropertyChange& what_chang
 		if (node.get_property (X_("position"), p) && node.get_property (X_("length"), l)) {
 			_length = timecnt_t (l, timepos_t (p));
 		}
+
+		std::string lock_style;
+		if (node.get_property (X_("positional-lock-style"), lock_style)) {
+			if (lock_style == "MusicTime") {
+				double beat, start_beats, length_beats;
+				if (node.get_property (X_("beat"), beat) && node.get_property (X_("length-beats"), length_beats)) {
+					_length = timecnt_t (Temporal::Beats::from_double (length_beats), timepos_t (Temporal::Beats::from_double (beat)));
+				}
+				if (node.get_property (X_("start-beats"), start_beats)) {
+					_start = timepos_t (Temporal::Beats::from_double (start_beats));
+				}
+			}
+		}
 	}
 
 	/* Regions derived from "Destructive/Tape" mode tracks in earlier
@@ -2058,6 +2073,12 @@ Region::source_beats_to_absolute_beats (Temporal::Beats beats) const
 	return source_position().beats() + beats;
 }
 
+Temporal::Beats
+Region::absolute_time_to_region_beats(timepos_t const & b) const
+{
+	 return (position().distance (b)).beats () + start().beats();;
+}
+
 Temporal::timepos_t
 Region::region_beats_to_absolute_time (Temporal::Beats beats) const
 {
@@ -2074,47 +2095,41 @@ Region::source_beats_to_absolute_time (Temporal::Beats beats) const
 	return source_position() + timepos_t (beats);
 }
 
+/** Calculate  (time - source_position) in Beats
+ *
+ * Measure the distance between the absolute time and the position of
+ * the source start, in beats. The result is positive if time is later
+ * than source position.
+ *
+ * @param p is an absolute time
+ * @returns time offset from p to the region's source position as the origin in Beat units
+ */
 Temporal::Beats
-Region::absolute_time_to_source_beats(timepos_t const & time) const
+Region::absolute_time_to_source_beats(timepos_t const& p) const
 {
-	/* measure the distance between the absolute time and the position of
-	   the source start, in beats. positive if time is later than source
-	   position.
-	*/
-
-	return source_position().distance (time).beats();
+	return source_position().distance (p).beats();
 }
 
-timepos_t
+/** Calculate (pos - source-position)
+ *
+ * @param p is an absolute time
+ * @returns time offset from p to the region's source position as the origin.
+ */
+timecnt_t
 Region::source_relative_position (timepos_t const & p) const
 {
-	/* p is an absolute time, return the time with the source position as
-	   the origin.
-
-	   Note that conventionally we would return a timecnt_t, expressing a
-	   distance from the source position. But we return timepos_t for which
-	   the origin is implicit, and in this case, the origin is the region
-	   position, not zero.
-
-	   XXX this seems likely to cause problems.
-	*/
-	return p.earlier (source_position());
+	return source_position().distance (p);
 }
 
-timepos_t
+/** Calculate (p - region-position)
+ *
+ * @param p is an absolute time
+ * @returns the time offset using the region (timeline) position as origin
+ */
+timecnt_t
 Region::region_relative_position (timepos_t const & p) const
 {
-	/* p is an absolute time, return the time with the region position as
-	   the origin.
-
-	   Note that conventionally we would return a timecnt_t, expressing a
-	   distance from the region position. But we return timepos_t for which
-	   the origin is implicit, and in this case, the origin is the region
-	   position, not zero.
-
-	   XXX this seems likely to cause problems.
-	*/
-	return p.earlier (position());
+	return position().distance (p);
 }
 
 Temporal::TimeDomain
