@@ -225,6 +225,7 @@ PulseAudioBackend::init_pulse ()
 	ba.fragsize  = 0; // capture only
 
 	if (!pa_sample_spec_valid (&ss)) {
+		PBD::error << _("PulseAudioBackend: Default sample spec not valid") << endmsg;
 		return AudioDeviceInvalidError;
 	}
 
@@ -273,7 +274,6 @@ PulseAudioBackend::init_pulse ()
 		close_pulse (true);
 		return AudioDeviceOpenError;
 	}
-
 	/* Wait until the context is ready, context_state_cb will trigger this */
 	pa_threaded_mainloop_wait (p_mainloop);
 	if (pa_context_get_state (p_context) != PA_CONTEXT_READY) {
@@ -317,10 +317,8 @@ PulseAudioBackend::init_pulse ()
 		close_pulse (true);
 		return AudioDeviceOpenError;
 	}
-
 	/* Wait until the stream is ready */
 	pa_threaded_mainloop_wait (p_mainloop);
-
 	if (pa_stream_get_state (p_stream) != PA_STREAM_READY) {
 		PBD::error << _("PulseAudioBackend: Failed to start stream") << endmsg;
 		close_pulse (true);
@@ -582,7 +580,7 @@ int
 PulseAudioBackend::_start (bool /*for_latency_measurement*/)
 {
 	if (!_active && _run) {
-		PBD::error << _("PulseAudioBackend: already active.") << endmsg;
+		PBD::error << _("PulseAudioBackend: restarting.") << endmsg;
 		/* recover from 'halted', reap threads */
 		stop ();
 	}
@@ -632,7 +630,6 @@ PulseAudioBackend::_start (bool /*for_latency_measurement*/)
 		if (pbd_pthread_create (PBD_RT_STACKSIZE_PROC, &_main_thread, pthread_process, this)) {
 			PBD::error << _("PulseAudioBackend: failed to create process thread.") << endmsg;
 			stop ();
-			_run = false;
 			return ProcessThreadStartError;
 		} else {
 			PBD::warning << _("PulseAudioBackend: cannot acquire realtime permissions.") << endmsg;
@@ -994,23 +991,16 @@ PulseAudioBackend::main_process_thread ()
 	manager.registration_callback ();
 	manager.graph_order_callback ();
 
-#if 0
-	/* flush stream */
-	pa_threaded_mainloop_lock (p_mainloop);
-	sync_pulse (pa_stream_flush (p_stream, stream_operation_cb, this));
-#endif
-
 	/* begin streaming */
 	if (!cork_pulse (false)) {
+		PBD::error << _("PulseAudioBackend::main_process_thread initial uncork failed.") << endmsg;
 		_active = false;
 		if (_run) {
 			engine.halted_callback ("PulseAudio: cannot uncork stream");
 		}
+		return 0;
 	}
 
-	pa_threaded_mainloop_lock (p_mainloop);
-	sync_pulse (pa_stream_drain (p_stream, stream_operation_cb, this));
-
 	_dsp_load_calc.reset ();
 	stream_latency_update_cb (p_stream, this);
 
@@ -1020,31 +1010,30 @@ PulseAudioBackend::main_process_thread ()
 			engine.freewheel_callback (_freewheel);
 
 			if (_freewheel) {
+				/* when transitioning to freewheeling, cork it and stop writing */
 				assert (!pa_stream_is_corked (p_stream));
 				if (!cork_pulse (true)) {
+					PBD::error << _("PulseAudioBackend::main_process_thread failed to cork for freewheeling.") << endmsg;
 					break;
 				}
 			}
 
-			/* flush stream before and after freewheeling */
+			/* flush corked stream before and after freewheeling */
 			assert (pa_stream_is_corked (p_stream));
 			pa_threaded_mainloop_lock (p_mainloop);
 			_operation_succeeded = false;
 			if (!sync_pulse (pa_stream_flush (p_stream, stream_operation_cb, this)) || !_operation_succeeded) {
+				PBD::error << _("PulseAudioBackend::main_process_thread failed to flush.") << endmsg;
 				break;
 			}
 
 			if (!_freewheel) {
+				/* when transitioning from freewheeling, uncork after flushing and start writing */
 				if (!cork_pulse (false)) {
+					PBD::error << _("PulseAudioBackend::main_process_thread failed to uncork after freewheeling.") << endmsg;
 					break;
 				}
-#if 0
-				pa_threaded_mainloop_lock (p_mainloop);
-				_operation_succeeded = false;
-				if (!sync_pulse (pa_stream_drain (p_stream, stream_operation_cb, this)) || !_operation_succeeded) {
-					break;
-				}
-#endif
+
 				_dsp_load_calc.reset ();
 			}
 		}
@@ -1053,13 +1042,14 @@ PulseAudioBackend::main_process_thread ()
 			pa_threaded_mainloop_lock (p_mainloop);
 
 			size_t bytes_to_write = sizeof (float) * _samples_per_period * N_CHANNELS;
-			if (pa_stream_writable_size (p_stream) < bytes_to_write) {
+			while (pa_stream_writable_size (p_stream) < bytes_to_write) {
 				/* wait until stream_request_cb triggers */
 				pa_threaded_mainloop_wait (p_mainloop);
 			}
 
 			if (pa_stream_get_state (p_stream) != PA_STREAM_READY) {
 				pa_threaded_mainloop_unlock (p_mainloop);
+				PBD::error << _("PulseAudioBackend::main_process_thread not ready when writing.") << endmsg;
 				break;
 			}
 
@@ -1069,6 +1059,7 @@ PulseAudioBackend::main_process_thread ()
 			if (engine.process_callback (_samples_per_period)) {
 				pa_threaded_mainloop_unlock (p_mainloop);
 				_active = false;
+				PBD::error << _("PulseAudioBackend::main_process_thread engine.process_callback failed.") << endmsg;
 				return 0;
 			}
 
@@ -1079,8 +1070,7 @@ PulseAudioBackend::main_process_thread ()
 
 			/* interleave */
 			for (std::vector<BackendPortPtr>::const_iterator it = _system_outputs.begin (); it != _system_outputs.end (); ++it, ++i) {
-				BackendPortPtr port = boost::dynamic_pointer_cast<BackendPort> (*it);
-				const float* src = (const float*) port->get_buffer (_samples_per_period);
+				const float* src = (const float*) (*it)->get_buffer (_samples_per_period);
 				for (size_t n = 0; n < _samples_per_period; ++n) {
 					buf[N_CHANNELS * n + i] = src[n];
 				}
@@ -1088,8 +1078,10 @@ PulseAudioBackend::main_process_thread ()
 
 			if (pa_stream_write (p_stream, buf, bytes_to_write, NULL, 0, PA_SEEK_RELATIVE) < 0) {
 				pa_threaded_mainloop_unlock (p_mainloop);
+				PBD::error << _("PulseAudioBackend::main_process_thread pa_stream_write failed.") << endmsg;
 				break;
 			}
+
 			pa_threaded_mainloop_unlock (p_mainloop);
 
 			_processed_samples += _samples_per_period;
@@ -1103,6 +1095,7 @@ PulseAudioBackend::main_process_thread ()
 			_last_process_start = 0;
 			if (engine.process_callback (_samples_per_period)) {
 				_active = false;
+				PBD::error << _("PulseAudioBackend::main_process_thread freewheeling engine.process_callback failed.") << endmsg;
 				return 0;
 			}
 
@@ -1237,7 +1230,7 @@ PulseAudioPort::get_buffer (pframes_t n_samples)
 			while (++it != connections.end ()) {
 				source = boost::dynamic_pointer_cast<PulseAudioPort> (*it);
 				assert (source && source->is_output ());
-				Sample*       dst = buffer ();
+				Sample*       dst = _buffer;
 				const Sample* src = source->const_buffer ();
 				for (uint32_t s = 0; s < n_samples; ++s, ++dst, ++src) {
 					*dst += *src;
