@@ -194,8 +194,6 @@ FaderPort::FaderPort (Session& s)
 
 FaderPort::~FaderPort ()
 {
-	cerr << "~FP\n";
-
 	close ();
 
 	if (_input_port) {
@@ -367,7 +365,7 @@ FaderPort::button_handler (MIDI::Parser &, MIDI::EventTwoBytes* tb)
 		if (_current_stripable) {
 			boost::shared_ptr<AutomationControl> gain = _current_stripable->gain_control ();
 			if (gain) {
-				samplepos_t now = session->engine().sample_time();
+				timepos_t now = timepos_t (session->engine().sample_time());
 				if (tb->value) {
 					gain->start_touch (now);
 				} else {
@@ -673,6 +671,8 @@ FaderPort::map_recenable_state ()
 			onoff = blink_state;
 		}
 		break;
+	default:
+		return; /* stupid compilers */
 	}
 
 	if (onoff != rec_enable_state) {
@@ -737,7 +737,7 @@ FaderPort::midi_input_handler (Glib::IOCondition ioc, boost::weak_ptr<ARDOUR::As
 		return false;
 	}
 
-	DEBUG_TRACE (DEBUG::FaderPort, string_compose ("something happend on  %1\n", boost::shared_ptr<MIDI::Port>(port)->name()));
+	DEBUG_TRACE (DEBUG::FaderPort, string_compose ("something happened on  %1\n", boost::shared_ptr<MIDI::Port>(port)->name()));
 
 	if (ioc & ~IO_IN) {
 		return false;
@@ -756,7 +756,7 @@ FaderPort::midi_input_handler (Glib::IOCondition ioc, boost::weak_ptr<ARDOUR::As
 
 
 XMLNode&
-FaderPort::get_state ()
+FaderPort::get_state () const
 {
 	XMLNode& node (ControlProtocol::get_state());
 
