@@ -395,6 +395,12 @@ OSC_GUI::OSC_GUI (OSC& p)
 	fbtable->attach (use_osc10, 1, 2, fn, fn+1, AttachOptions(FILL|EXPAND), AttachOptions(0), 0, 0);
 	++fn;
 
+	label = manage (new Gtk::Label(_("Report 8x8 Trigger Grid status:")));
+	label->set_alignment(1, .5);
+	fbtable->attach (*label, 0, 1, fn, fn+1, AttachOptions(FILL|EXPAND), AttachOptions(0));
+	fbtable->attach (trigger_status, 1, 2, fn, fn+1, AttachOptions(FILL|EXPAND), AttachOptions(0), 0, 0);
+	++fn;
+
 	fbtable->show_all ();
 	append_page (*fbtable, _("Default Feedback"));
 	// set strips and feedback from loaded default values
@@ -426,6 +432,7 @@ OSC_GUI::OSC_GUI (OSC& p)
 	hp_gui.signal_clicked().connect (sigc::mem_fun (*this, &OSC_GUI::set_bitsets));
 	select_fb.signal_clicked().connect (sigc::mem_fun (*this, &OSC_GUI::set_bitsets));
 	use_osc10.signal_clicked().connect (sigc::mem_fun (*this, &OSC_GUI::set_bitsets));
+	trigger_status.signal_clicked().connect (sigc::mem_fun (*this, &OSC_GUI::set_bitsets));
 	preset_busy = false;
 
 }
@@ -680,6 +687,7 @@ OSC_GUI::reshow_values ()
 	//hp_gui.set_active (false); // we don't have this yet (Mixbus wants)
 	select_fb.set_active(def_feedback & 8192);
 	use_osc10.set_active(def_feedback & 16384);
+	trigger_status.set_active(def_feedback & 32768);
 
 	calculate_strip_types ();
 	calculate_feedback ();
@@ -734,6 +742,9 @@ OSC_GUI::calculate_feedback ()
 	if (use_osc10.get_active()) {
 		fbvalue += 16384;
 	}
+	if (trigger_status.get_active()) {
+		fbvalue += 32768;
+	}
 
 	current_feedback.set_text(string_compose("%1", fbvalue));
 }
