@@ -201,9 +201,9 @@ timecnt_t
 timecnt_t::scale (ratio_t const & r) const
 {
 	if (time_domain() == AudioTime) {
-		return timecnt_t::from_superclock (PBD::muldiv (_distance.val(), r.numerator(), r.denominator()), _position);
+		return timecnt_t::from_superclock (PBD::muldiv_round (_distance.val(), r.numerator(), r.denominator()), _position);
 	} else {
-		return timecnt_t::from_ticks (PBD::muldiv (_distance.val(), r.numerator(), r.denominator()), _position);
+		return timecnt_t::from_ticks (PBD::muldiv_round (_distance.val(), r.numerator(), r.denominator()), _position);
 	}
 }
 
@@ -280,6 +280,8 @@ timecnt_t::string_to (std::string const & str)
 		ss >> ticks;
 		_distance = int62_t (true, ticks);
 		break;
+	default:
+		return false;
 	}
 
 	/* eat separator character */
@@ -590,9 +592,9 @@ timepos_t
 timepos_t::scale (ratio_t const & n) const
 {
 	if (time_domain() == AudioTime) {
-		return timepos_t::from_superclock (PBD::muldiv (val(), n.numerator(), n.denominator()));
+		return timepos_t::from_superclock (PBD::muldiv_round (val(), n.numerator(), n.denominator()));
 	} else {
-		return timepos_t::from_ticks (PBD::muldiv (val(), n.numerator(), n.denominator()));
+		return timepos_t::from_ticks (PBD::muldiv_round (val(), n.numerator(), n.denominator()));
 	}
 }
 
@@ -617,7 +619,7 @@ timepos_t::expensive_add (timepos_t const & other) const
 
 /* */
 
-/* ::distance() assumes that @param other is later on the timeline than this, and
+/* ::distance() assumes that @p other is later on the timeline than this, and
  * thus returns a positive value if this condition is satisfied.
  */
 
